##  Step 2: Create a Webhook for Fact Sheet Relations
Create a PUSH webhook for the RELATION_CREATED and RELATION_UPDATED events. For instructions, see [Creating a Webhook](https://help.sap.com/docs/leanix/ea/webhooks?locale=en-US&state=PRODUCTION&version=CLOUD#loio275e18367a441014869bb7aa3562039e__creating_a_webhook).
To test the automation, use a test target URL. If the automation works as expected, replace the test URL with the function URL.
